@@ -55,6 +55,7 @@ class SKLLConfigParser(configparser.ConfigParser):
         defaults = {'class_map': '{}',
                     'custom_learner_path': '',
                     'custom_metric_path': '',
+                    'cv_seed': '123456789',
                     'folds_file': '',
                     'feature_hasher': 'False',
                     'feature_scaling': 'none',
@@ -68,7 +69,6 @@ class SKLLConfigParser(configparser.ConfigParser):
                     'id_col': 'id',
                     'ids_to_floats': 'False',
                     'label_col': 'y',
-                    'log': '',
                     'logs': '',
                     'learning_curve_cv_folds_list': '[]',
                     'learning_curve_train_sizes': '[]',
@@ -78,7 +78,7 @@ class SKLLConfigParser(configparser.ConfigParser):
                     'metrics': "[]",
                     'objectives': "[]",
                     'param_grids': '[]',
-                    'pos_label_str': '',
+                    'pos_label': '',
                     'pipeline': 'False',
                     'predictions': '',
                     'probability': 'False',
@@ -100,6 +100,7 @@ class SKLLConfigParser(configparser.ConfigParser):
         correct_section_mapping = {'class_map': 'Input',
                                    'custom_learner_path': 'Input',
                                    'custom_metric_path': 'Input',
+                                   'cv_seed': 'Input',
                                    'folds_file': 'Input',
                                    'feature_hasher': 'Input',
                                    'feature_scaling': 'Input',
@@ -113,7 +114,6 @@ class SKLLConfigParser(configparser.ConfigParser):
                                    'id_col': 'Input',
                                    'ids_to_floats': 'Input',
                                    'label_col': 'Input',
-                                   'log': 'Output',
                                    'logs': 'Output',
                                    'learning_curve_cv_folds_list': 'Input',
                                    'learning_curve_train_sizes': 'Input',
@@ -123,7 +123,7 @@ class SKLLConfigParser(configparser.ConfigParser):
                                    'num_cv_folds': 'Input',
                                    'objectives': 'Tuning',
                                    'param_grids': 'Tuning',
-                                   'pos_label_str': 'Tuning',
+                                   'pos_label': 'Tuning',
                                    'pipeline': 'Output',
                                    'predictions': 'Output',
                                    'probability': 'Output',
@@ -184,6 +184,7 @@ class SKLLConfigParser(configparser.ConfigParser):
         -------
         incorrectly_specified_options : list of str
             A list of incorrectly specified options.
+
         multiply_specified_options : list of str
             A list of options specified more than once.
 
@@ -225,8 +226,10 @@ class SKLLConfigParser(configparser.ConfigParser):
         ------
         KeyError
             If configuration file contains unrecognized options.
+
         KeyError
             If any options are defined in multiple sections.
+
         KeyError
             If any options are not defined in the appropriate sections.
         """
@@ -254,9 +257,11 @@ def parse_config_file(config_path, log_level=logging.INFO):  # noqa: C901
     ----------
     config_path : str
         The path to the configuration file.
-    log_level : logging level, optional
-        The logging level to use.
-        Defaults to ``logging.INFO``.
+
+    log_level : int, default=logging.INFO
+        Determines which messages should be logged. You can either pass
+        an integer or one of the corresponding ``logging`` parameters, such
+        as ``logging.INFO`` or ``logging.WARNING``.
 
     Returns
     -------
@@ -264,105 +269,154 @@ def parse_config_file(config_path, log_level=logging.INFO):  # noqa: C901
         A string used to identify this particular experiment configuration.
         When generating result summary files, this name helps prevent
         overwriting previous summaries.
+
     task : str
         The types of experiment we're trying to run (e.g. 'cross_validate').
+
     sampler : str
         The name of a sampler to perform non-linear transformations of the input.
+
     fixed_sampler_parameters : dict
-        A dictionary containing parameters you want to have fixed for the sampler
+        A dictionary containing parameters you want to have fixed for the sampler.
+
     feature_hasher : bool
         If True, this enables a high-speed, low-memory vectorizer that uses
         feature hashing for converting feature dictionaries into NumPy arrays
         instead of using a DictVectorizer.
+
     hasher_features : int
         The number of features used by the FeatureHasher if the feature_hasher
         flag is enabled.
+
     id_col : str
         The column with IDs.
+
     label_col : str
         The column with labels.
+
     train_set_name : str
         The name of the training set.
+
     test_set_name : str
         The name of the test set.
+
     suffix : str
         The file format the training/test files are in.
+
     featuresets : list of str
         A list of lists of prefixes for the files containing
         the features you would like to train/test on.
+
     do_shuffle : bool
         Whether to shuffle the data.
+
     model_path : str
         The path to the model file(s).
+
     do_grid_search : bool
         Whether to perform grid search.
+
     grid_objectives : list of str
         A list of scoring functions to use for tuning.
+
     probability : bool
         Whether to output probabilities for each class.
+
     pipeline : bool
         Whether to include the `pipeline` attribute in the
         trained model. This will increase the size of the
         model file.
+
     results_path : str
         Path to store result files in.
-    pos_label_str : str
+
+    pos_label : str
         The string label for the positive class in the binary
         classification setting.
+
     feature_scaling : str
         How to scale features (e.g. 'with_mean').
+
     min_feature_count : int
         The minimum number of examples for which the value of a
         feature must be nonzero to be included in the model.
+
     folds_file : str
         The path to the folds_file, if specified.
+
     grid_search_jobs : int
         Number of folds to run in parallel when using grid search.
+
     grid_search_folds : int
         The number of folds to use for grid search.
+
     cv_folds : dict or int
         The specified folds mapping, or the number of folds.
+
+    cv_seed : int
+        The seed value for the random number generator used
+        to create the cross-validation folds.
+
     save_cv_folds : bool
         Whether to save CV Folds to file.
+
     save_cv_models : bool
         Whether to save CV models.
+
     use_folds_file_for_grid_search : bool
         Whether to use folds file for grid search.
+
     do_stratified_folds : bool
         Whether to use random folds for cross-validation.
+
     fixed_parameter_list : list of dict
         List of dicts containing parameters you want to have fixed for
         each classifier in learners list.
+
     param_grid_list : list of dict
         List of parameter grids to search, one dict for each learner.
+
     featureset_names : list of str
         The names of the featuresets used for each job.
+
     learners : list of str
         A list of learners to try using.
+
     prediction_dir : str
         The directories where predictions are saved.
+
     log_path : str
         The path to the log file.
+
     train_path : str
         The path to a file containing feature to train on.
+
     test_path : str
         The path to a file containing features to test on.
+
     ids_to_floats : bool
         Whether to convert IDs to floats.
+
     class_map : dict
         A class map collapsing several labels into one.
+
     custom_learner_path : str
         Path to a .py file that defines a custom learner.
+
     custom_metric_path : str
         Path to a .py file that defines a custom metric.
+
     learning_curve_cv_folds_list : list of int
         A list of integers specifying the number of folds to use for CV.
+
     learning_curve_train_sizes : list of float or list of int
         List of floats or integers representing relative or absolute numbers
         of training examples that will be used to generate the learning
         curve respectively.
+
     output_metrics : list
         A list of output metrics to use.
+
     save_votes : bool
         Whether to save the individual predictions from voting learners.
 
@@ -370,6 +424,7 @@ def parse_config_file(config_path, log_level=logging.INFO):  # noqa: C901
     ------
     IOError
         If configuration file name is empty
+
     ValueError
         If various configuration parameters are incorrectly specified,
         or cause conflicts.
@@ -400,18 +455,6 @@ def parse_config_file(config_path, log_level=logging.INFO):  # noqa: C901
     # next, get the log path before anything else since we need to
     # save all logging messages to a log file in addition to displaying
     # them on the console
-
-    # if the user specified "log" instead of "logs", we need
-    # to show a warning and save its value in "logs" instead
-    log_value = config.get("Output", "log")
-    show_log_warning = False
-    if log_value:
-        # since we do not have a logger yet, we will show the warning later
-        show_log_warning = True
-        config.set('Output', 'logs', log_value)
-        config.remove_option('Output', 'log')
-
-    # now get the value from the 'logs' field
     log_value = config.get("Output", "logs")
 
     try:
@@ -432,13 +475,6 @@ def parse_config_file(config_path, log_level=logging.INFO):  # noqa: C901
                              filepath=main_log_file,
                              log_level=log_level)
 
-    # now show the 'log' warning, if any, since we have the logger set up
-    if show_log_warning:
-        logger.warning("The 'log' option in the [Output] section is deprecated "
-                       "and will be removed in the next version. Use 'logs' "
-                       "instead.")
-        show_log_warning = False
-
     if config.has_option("General", "task"):
         task = config.get("General", "task")
     else:
@@ -562,10 +598,10 @@ def parse_config_file(config_path, log_level=logging.INFO):  # noqa: C901
     fixed_sampler_parameters = yaml.safe_load(fixed_sampler_parameters)
     param_grid_list = yaml.safe_load(fix_json(config.get("Tuning", "param_grids")))
 
-    # read and normalize the value of `pos_label_str`
-    pos_label_str = safe_float(config.get("Tuning", "pos_label_str"))
-    if pos_label_str == '':
-        pos_label_str = None
+    # read and normalize the value of `pos_label`
+    pos_label = safe_float(config.get("Tuning", "pos_label"))
+    if pos_label == '':
+        pos_label = None
 
     # ensure that feature_scaling is specified only as one of the
     # four available choices
@@ -579,6 +615,9 @@ def parse_config_file(config_path, log_level=logging.INFO):  # noqa: C901
     id_col = config.get("Input", "id_col")
     ids_to_floats = config.getboolean("Input", "ids_to_floats")
 
+    # read in the cross-validation seed
+    cv_seed = config.getint("Input", "cv_seed")
+
     # if an external folds file is specified, then read it into a dictionary
     folds_file = locate_file(config.get("Input", "folds_file"), config_dir)
     num_cv_folds = config.getint("Input", "num_cv_folds")
@@ -854,8 +893,8 @@ def parse_config_file(config_path, log_level=logging.INFO):  # noqa: C901
             feature_hasher, hasher_features, id_col, label_col, train_set_name,
             test_set_name, suffix, featuresets, do_shuffle, model_path,
             do_grid_search, grid_objectives, probability, pipeline, results_path,
-            pos_label_str, feature_scaling, min_feature_count, folds_file,
-            grid_search_jobs, grid_search_folds, cv_folds, save_cv_folds,
+            pos_label, feature_scaling, min_feature_count, folds_file,
+            grid_search_jobs, grid_search_folds, cv_folds, cv_seed, save_cv_folds,
             save_cv_models, use_folds_file_for_grid_search, do_stratified_folds,
             fixed_parameter_list, param_grid_list, featureset_names, learners,
             prediction_dir, log_path, train_path, test_path, ids_to_floats,
@@ -873,9 +912,9 @@ def _setup_config_parser(config_path, validate=True):
     ----------
     config_path : str
         The path to the configuration file.
-    validate : bool, optional
+
+    validate : bool, default=True
         Whether to validate the configuration file.
-        Defaults to ``True``.
 
     Returns
     -------
