@@ -66,7 +66,7 @@ from sklearn.utils.multiclass import type_of_target
 from skll.data import FeatureSet
 from skll.data.dict_vectorizer import DictVectorizer
 from skll.data.readers import safe_float
-from skll.metrics import SCORERS
+from skll.metrics import _SCORERS
 from skll.utils.constants import (
     CORRELATION_METRICS,
     KNOWN_DEFAULT_PARAM_GRIDS,
@@ -257,7 +257,7 @@ class Learner(object):
             self._model_kwargs['cache_size'] = 1000
             self._model_kwargs['gamma'] = 'scale'
         elif issubclass(self._model_type, SGDClassifier):
-            self._model_kwargs['loss'] = 'log'
+            self._model_kwargs['loss'] = 'log_loss'
             self._model_kwargs['max_iter'] = 1000
             self._model_kwargs['tol'] = 1e-3
         elif issubclass(self._model_type, SGDRegressor):
@@ -315,17 +315,19 @@ class Learner(object):
             self.sampler = None
 
         if model_kwargs:
-            # if the model is an AdaBoost classifier or regressor or
-            # a RANSAC regressor, then we need to convert any specified
-            # `base_estimator` (a string) into an object before passing
-            # it in to the learner constructor. We also need to make sure
-            # where appropriate, we set the random state to a fixed seed
-            # such that results are replicable
-            if issubclass(self._model_type,
-                          (AdaBoostRegressor,
-                           AdaBoostClassifier,
-                           RANSACRegressor)) and ('base_estimator' in model_kwargs):
-                base_estimator_name = model_kwargs['base_estimator']
+            # if the model is an AdaBoost classifier or regressor (or
+            # a RANSAC regressor), then we need to convert the specified
+            # `base_estimator` (or `estimator`) string into an object
+            # before passing it in to the learner constructor. We also
+            # need to make sure where appropriate, we set the random state
+            # to a fixed seed such that results are replicable
+            is_ada_has_base_estimator = (issubclass(self._model_type, (AdaBoostRegressor,
+                                                                       AdaBoostClassifier))
+                                         and 'base_estimator' in model_kwargs)
+            is_ransac_has_estimator = (issubclass(self._model_type, RANSACRegressor)
+                                       and 'estimator' in model_kwargs)
+            if is_ada_has_base_estimator or is_ransac_has_estimator:
+                base_estimator_name = model_kwargs.get('base_estimator', model_kwargs.get('estimator'))
                 if base_estimator_name in ['LinearRegression', 'MultinomialNB']:
                     base_estimator_kwargs = {}
                 elif base_estimator_name in ['SGDClassifier', 'SGDRegressor']:
@@ -339,7 +341,11 @@ class Learner(object):
                 else:
                     base_estimator_kwargs = {'random_state': 123456789}
                 base_estimator = globals()[base_estimator_name](**base_estimator_kwargs)
-                model_kwargs['base_estimator'] = base_estimator
+                # RANSACRegressor uses 'estimator' instead of 'base_estimator'
+                if is_ransac_has_estimator:
+                    model_kwargs['estimator'] = base_estimator
+                else:
+                    model_kwargs['base_estimator'] = base_estimator
             self._model_kwargs.update(model_kwargs)
 
     @classmethod
@@ -634,6 +640,24 @@ class Learner(object):
 
         return estimator, default_param_grid
 
+    def get_feature_names_out(self):
+        """
+        Return the names of the actual features used by the estimator.
+
+        It is possible for some features to get filtered out by the
+        feature selector which means that the vectorizer is no
+        longer the correct source for the feature names. This
+        method takes into account the feature selector and returns
+        the names of the features that were actually selected to be
+        used by the estimator.
+
+        Returns
+        -------
+        names : 1-D array
+            Names of features actually used by the estimator.
+        """
+        return self.feat_vectorizer.get_feature_names_out()[self.feat_selector.get_support()]
+
     def _check_input_formatting(self, examples):
         """
         check that the examples are properly formatted.
@@ -871,9 +895,9 @@ class Learner(object):
                 new_grid_objective = f'{grid_objective}_probs'
                 metrics_module = import_module('skll.metrics')
                 metric_func = getattr(metrics_module, 'correlation')
-                SCORERS[new_grid_objective] = make_scorer(metric_func,
-                                                          corr_type=grid_objective,
-                                                          needs_proba=True)
+                _SCORERS[new_grid_objective] = make_scorer(metric_func,
+                                                           corr_type=grid_objective,
+                                                           needs_proba=True)
                 grid_objective = new_grid_objective
 
         # Shuffle so that the folds are random for the inner grid search CV.
@@ -1026,7 +1050,7 @@ class Learner(object):
         # objectives and probability outputs
         if 'old_grid_objective' in locals():
             grid_objective = old_grid_objective
-            del SCORERS[new_grid_objective]
+            del _SCORERS[new_grid_objective]
 
         # store a scikit-learn Pipeline in the `pipeline` attribute
         # composed of a copy of the vectorizer, the selector,
